==> core-react-0.8.0.tgz: package/es/AvatarUpload/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Avatar from '../Avatar';


var AvatarUpload = /*#__PURE__*/function (_Component) {
  _inherits(AvatarUpload, _Component);

  function AvatarUpload() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, AvatarUpload);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(AvatarUpload)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      var onClick = _this.props.onClick;

      if (onClick) {
        onClick(e);
      }
    });

    return _this;
  }

  _createClass(AvatarUpload, [{
    key: "render",
    value: function render() {
      var _cx, _cx2;

      var _this$props = this.props,
          shape = _this$props.shape,
          size = _this$props.size,
          src = _this$props.src,
          className = _this$props.className,
          text = _this$props.text;
      return React.createElement("div", {
        className: "".concat("waui", "-avatar-upload")
      }, src ? React.createElement("div", {
        className: "".concat("waui", "-avatar-upload__update")
      }, React.createElement(Avatar, {
        src: src,
        shape: shape,
        size: size,
        onClick: this.handleClick
      }), React.createElement("div", {
        onClick: this.handleClick,
        className: cx("".concat("waui", "-avatar-upload__cover"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-avatar-upload__cover_").concat(shape), shape), _defineProperty(_cx, "".concat("waui", "-avatar-upload__cover_").concat(size), size), _cx), className)
      }, text)) : React.createElement("div", {
        onClick: this.handleClick,
        className: cx("".concat("waui", "-avatar-upload__first"), (_cx2 = {}, _defineProperty(_cx2, "".concat("waui", "-avatar-upload__shallow-cover_").concat(shape), shape), _defineProperty(_cx2, "".concat("waui", "-avatar-upload__shallow-cover_").concat(size), size), _cx2), className)
      }, text));
    }
  }]);

  return AvatarUpload;
}(Component);

AvatarUpload.propTypes = {
  className: PropTypes.string,

  /** The shape of avatar, default value is `circle` */
  shape: PropTypes.oneOf(['square', 'circle']),

  /** The size of avatar */
  size: PropTypes.oneOf(['lg', 'xl']),

  /** The url of image */
  src: PropTypes.string,

  /** The caption of avatar when hovering the avatar */
  text: PropTypes.string,

  /** The callback of clicking avatar */
  onClick: PropTypes.func
};
AvatarUpload.defaultProps = {
  shape: 'circle',
  src: ''
};
export default AvatarUpload;

==> core-react-0.8.2.tgz: package/es/AvatarUpload/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Avatar from '../Avatar';


var AvatarUpload = /*#__PURE__*/function (_Component) {
  _inherits(AvatarUpload, _Component);

  function AvatarUpload() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, AvatarUpload);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(AvatarUpload)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      var onClick = _this.props.onClick;

      if (onClick) {
        onClick(e);
      }
    });

    return _this;
  }

  _createClass(AvatarUpload, [{
    key: "render",
    value: function render() {
      var _cx, _cx2;

      var _this$props = this.props,
          shape = _this$props.shape,
          size = _this$props.size,
          src = _this$props.src,
          className = _this$props.className,
          text = _this$props.text;
      return (/*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-avatar-upload")
        }, src ? /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-avatar-upload__update")
        }, /*#__PURE__*/React.createElement(Avatar, {
          src: src,
          shape: shape,
          size: size,
          onClick: this.handleClick
        }), /*#__PURE__*/React.createElement("div", {
          onClick: this.handleClick,
          className: cx("".concat("waui", "-avatar-upload__cover"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-avatar-upload__cover_").concat(shape), shape), _defineProperty(_cx, "".concat("waui", "-avatar-upload__cover_").concat(size), size), _cx), className)
        }, text)) : /*#__PURE__*/React.createElement("div", {
          onClick: this.handleClick,
          className: cx("".concat("waui", "-avatar-upload__first"), (_cx2 = {}, _defineProperty(_cx2, "".concat("waui", "-avatar-upload__shallow-cover_").concat(shape), shape), _defineProperty(_cx2, "".concat("waui", "-avatar-upload__shallow-cover_").concat(size), size), _cx2), className)
        }, text))
      );
    }
  }]);

  return AvatarUpload;
}(Component);

AvatarUpload.propTypes = {
  className: PropTypes.string,

  /** The shape of avatar, default value is `circle` */
  shape: PropTypes.oneOf(['square', 'circle']),

  /** The size of avatar */
  size: PropTypes.oneOf(['lg', 'xl']),

  /** The url of image */
  src: PropTypes.string,

  /** The caption of avatar when hovering the avatar */
  text: PropTypes.string,

  /** The callback of clicking avatar */
  onClick: PropTypes.func
};
AvatarUpload.defaultProps = {
  shape: 'circle',
  src: ''
};
export default AvatarUpload;
